#[non_exhaustive]pub enum SubstitutionError {
RecursiveAssignment {
var_id: VariableID,
},
CyclicAssignmentDetected,
ParameterSubstitution {
parameter: VariableID,
},
UndefinedSubstitutionVariable {
variable: VariableID,
},
}Expand description
Error types that can occur during substitution operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RecursiveAssignment
Error indicating that a recursive assignment was attempted.
Fields

var_id: VariableIDCyclicAssignmentDetected
Error indicating that a cycle was detected in the assignment graph.
ParameterSubstitution
ParametricInstance::substitute only substitutes decision variables.
Fields

parameter: VariableIDUndefinedSubstitutionVariable
Substitution assignments may only reference IDs defined by the host.
Fields

variable: VariableIDTrait Implementations
Sourceimpl Clone for SubstitutionError
impl Clone for SubstitutionError
Sourcefn clone(&self) -> SubstitutionError
fn clone(&self) -> SubstitutionError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubstitutionError
impl Debug for SubstitutionError
Sourceimpl Display for SubstitutionError
impl Display for SubstitutionError
Sourceimpl Error for SubstitutionError
impl Error for SubstitutionError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<SubstitutionError> for RawParseError
impl From<SubstitutionError> for RawParseError
Sourcefn from(source: SubstitutionError) -> Self
fn from(source: SubstitutionError) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for SubstitutionError
impl PartialEq for SubstitutionError
Sourcefn eq(&self, other: &SubstitutionError) -> bool
fn eq(&self, other: &SubstitutionError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SubstitutionError
impl StructuralPartialEq for SubstitutionError