pub struct ConstraintHints {
pub one_hot_constraints: Vec<OneHot>,
pub sos1_constraints: Vec<Sos1>,
}Expand description
Constraint hints provide additional information about active constraints to help solvers optimize more efficiently.
Important
Constraint hints can only reference active constraints, not removed constraints.
When a constraint is relaxed (moved to removed_constraints), any associated hints
are automatically invalidated. When adding hints via crate::Instance::add_constraint_hints,
referencing a removed constraint will result in an error.
When parsing an instance from bytes, hints that reference removed or unknown constraints are discarded (with debug-level logging) for backward compatibility with legacy artifacts.
Fields
one_hot_constraints: Vec<OneHot>sos1_constraints: Vec<Sos1>Implementations
Sourceimpl ConstraintHints
impl ConstraintHints
pub fn is_empty(&self) -> bool
Sourcepub fn partial_evaluate(
&mut self,
state: State,
atol: ATol,
) -> Result<State, ConstraintHintsError>
pub fn partial_evaluate( &mut self, state: State, atol: ATol, ) -> Result<State, ConstraintHintsError>
Partially evaluate all constraint hints with the given state.
This method modifies the constraint hints in-place by:
- Removing constraints that are satisfied or cannot be satisfied
- Updating constraints by removing variables fixed to 0
Returns a new State containing the original state plus any additional variable fixings discovered through constraint propagation.
The process iterates until no more variable fixings are discovered, ensuring all constraint propagations are applied.