pub struct DecisionVariableUsageEntry { /* private fields */ }Expand description
Reverse-usage entry for one used decision variable.
A variable has an entry here only when it appears in the objective or an active constraint family that contributes to solver input. Fixed, dependent, and irrelevant variables do not have usage entries.
Implementations
Sourceimpl DecisionVariableUsageEntry
impl DecisionVariableUsageEntry
pub fn used_in_objective(&self) -> bool
pub fn used_in_regular_constraints(&self) -> &BTreeSet<ConstraintID>
pub fn used_in_indicator_constraints(&self) -> &BTreeSet<IndicatorConstraintID>
pub fn used_in_one_hot_constraints(&self) -> &BTreeSet<OneHotConstraintID>
pub fn used_in_sos1_constraints(&self) -> &BTreeSet<Sos1ConstraintID>
pub fn is_used_by_solver(&self) -> bool