CoefficientArithmeticResult

Type Alias CoefficientArithmeticResult 

pub type CoefficientArithmeticResult = Result<Option<Coefficient>, CoefficientError>;
Result of coefficient arithmetic.

  • Ok(Some(coefficient)): the result is a finite non-zero coefficient.
  • Ok(None): the result is exactly zero, so the owning polynomial term should be removed.
  • Err(error): the result is NaN or infinite and cannot be represented as a coefficient.

Aliased Type

pub enum CoefficientArithmeticResult {
    Ok(Option<Coefficient>),
    Err(CoefficientError),
}

Variants

1.0.0

Ok(Option<Coefficient>)

Contains the success value

1.0.0

Err(CoefficientError)

Contains the error value