#[non_exhaustive]#[repr(i32)]pub enum Optimality {
Unspecified = 0,
Optimal = 1,
NotOptimal = 2,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified = 0
The solver cannot determine whether the solution is optimal. Most of heuristic solvers should use this value.
Optimal = 1
The solver has determined that the solution is optimal.
NotOptimal = 2
The solver has determined that the solution is not optimal.
Implementations
Sourceimpl Optimality
impl Optimality
Sourceimpl Optimality
impl Optimality
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.