#[non_exhaustive]pub struct EvaluatedConstraint {
pub id: u64,
pub equality: i32,
pub evaluated_value: f64,
pub used_decision_variable_ids: Vec<u64>,
pub subscripts: Vec<i64>,
pub parameters: HashMap<String, String>,
pub name: Option<String>,
pub description: Option<String>,
pub dual_variable: Option<f64>,
pub removed_reason: Option<String>,
pub removed_reason_parameters: HashMap<String, String>,
}Expand description
A constraint evaluated with a state
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: u64equality: i32evaluated_value: f64The value of function for the state
used_decision_variable_ids: Vec<u64>IDs of decision variables used to evaluate this constraint
subscripts: Vec<i64>Integer parameters of the constraint.
parameters: HashMap<String, String>Key-value parameters of the constraint.
name: Option<String>Name of the constraint.
description: Option<String>Detail human-readable description of the constraint.
dual_variable: Option<f64>Value for the Lagrangian dual variable of this constraint. This is optional because not all solvers support to evaluate dual variables.
removed_reason: Option<String>Short removed reason of the constraint. This field exists only if this message is evaluated from a removed constraint.
removed_reason_parameters: HashMap<String, String>Detailed parameters why the constraint is removed. This field exists only if this message is evaluated from a removed constraint.
Implementations
Sourceimpl EvaluatedConstraint
impl EvaluatedConstraint
Sourcepub fn equality(&self) -> Equality
pub fn equality(&self) -> Equality
Returns the enum value of equality, or the default if the field is set to an invalid enum value.
Sourcepub fn set_equality(&mut self, value: Equality)
pub fn set_equality(&mut self, value: Equality)
Sets equality to the provided enum value.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn dual_variable(&self) -> f64
pub fn dual_variable(&self) -> f64
Returns the value of dual_variable, or the default value if dual_variable is unset.
Sourcepub fn removed_reason(&self) -> &str
pub fn removed_reason(&self) -> &str
Returns the value of removed_reason, or the default value if removed_reason is unset.
Sourceimpl EvaluatedConstraint
impl EvaluatedConstraint
pub fn is_feasible(&self, atol: ATol) -> Result<bool>