#[non_exhaustive]pub struct ProcessMetadata {
pub instance: Option<String>,
pub solver: Option<String>,
pub parameters: Option<String>,
pub start: Option<String>,
pub end: Option<String>,
}Expand description
Metadata for an optimization or sampling process that produced a Solution or SampleSet.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance: Option<String>Digest of the corresponding Instance, when this output is stored with one.
solver: Option<String>Solver or sampler information encoded as JSON.
parameters: Option<String>Solver or sampler parameters encoded as JSON.
start: Option<String>Solver or sampler start time encoded as an RFC3339 string.
end: Option<String>Solver or sampler end time encoded as an RFC3339 string.
Implementations
Sourceimpl ProcessMetadata
impl ProcessMetadata
Sourcepub fn instance(&self) -> &str
pub fn instance(&self) -> &str
Returns the value of instance, or the default value if instance is unset.
Sourcepub fn solver(&self) -> &str
pub fn solver(&self) -> &str
Returns the value of solver, or the default value if solver is unset.
Sourcepub fn parameters(&self) -> &str
pub fn parameters(&self) -> &str
Returns the value of parameters, or the default value if parameters is unset.