#[non_exhaustive]pub struct SampledDecisionVariable {
pub decision_variable: Option<DecisionVariable>,
pub samples: Option<SampledValues>,
}Expand description
A pair of decision variable description and its sampled values
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.decision_variable: Option<DecisionVariable>samples: Option<SampledValues>Sampled values of decision variable.
This becomes None if the decision variable is not sampled.