Solution

Struct Solution 

#[non_exhaustive]
pub struct Solution { pub state: Option<State>, pub objective: f64, pub decision_variables: Vec<DecisionVariable>, pub evaluated_constraints: Vec<EvaluatedConstraint>, pub evaluated_named_functions: Vec<EvaluatedNamedFunction>, pub feasible: bool, pub feasible_relaxed: Option<bool>, pub feasible_unrelaxed: bool, pub optimality: i32, pub relaxation: i32, pub sense: i32, }
Solution with evaluated objective and constraints

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
state: Option<State>objective: f64decision_variables: Vec<DecisionVariable>evaluated_constraints: Vec<EvaluatedConstraint>evaluated_named_functions: Vec<EvaluatedNamedFunction>feasible: bool

The feasibility of the solution for all, remaining and removed constraints.

The feasibility for the remaining constraints is represented by the feasible_relaxed field.

feasible_relaxed: Option<bool>

Feasibility of the solution for remaining constraints, ignoring removed constraints.

This is optional due to the backward compatibility. If this field is NULL, the feasible field represents relaxed feasibility, and the deprecated feasible_unrelaxed field represents the feasibility including removed constraints.

feasible_unrelaxed: bool
👎Deprecated

[DEPRECATED] Feasibility of the solution for all constraints. This field has been introduced in Python SDK 1.6.0 and deprecated in 1.7.0. The feasibility in this sense is represented by the feasible field after 1.7.0.

optimality: i32

The optimality of the solution.

relaxation: i32

Whether the solution is obtained by a relaxed linear programming solver.

sense: i32

Whether the problem is a minimization or maximization problem.

Implementations

Source

impl Solution

pub fn optimality(&self) -> Optimality

Returns the enum value of optimality, or the default if the field is set to an invalid enum value.

pub fn set_optimality(&mut self, value: Optimality)

Sets optimality to the provided enum value.

pub fn relaxation(&self) -> Relaxation

Returns the enum value of relaxation, or the default if the field is set to an invalid enum value.

pub fn set_relaxation(&mut self, value: Relaxation)

Sets relaxation to the provided enum value.

pub fn feasible_relaxed(&self) -> bool

Returns the value of feasible_relaxed, or the default value if feasible_relaxed is unset.

pub fn sense(&self) -> Sense

Returns the enum value of sense, or the default if the field is set to an invalid enum value.

pub fn set_sense(&mut self, value: Sense)

Sets sense to the provided enum value.

Source

impl Solution