#[non_exhaustive]pub struct ModelingLabel {
pub name: Option<String>,
pub subscripts: Vec<i64>,
pub parameters: BTreeMap<String, String>,
pub description: Option<String>,
}Expand description
Human-authored modeling notation for one table or collection row.
This label preserves the mathematical model notation before the model was
lowered into OMMX. For example, a variable written as x\[i, j\] can be
represented as name = "x" and subscripts = \[i, j\].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>subscripts: Vec<i64>parameters: BTreeMap<String, String>description: Option<String>Implementations
Sourceimpl ModelingLabel
impl ModelingLabel