#[non_exhaustive]pub enum Result {
Error(String),
Solution(Solution),
Infeasible(Infeasible),
Unbounded(Unbounded),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Error(String)
Error information by the solver which cannot be expressed by other messages. This string should be human-readable.
Solution(Solution)
Some feasible or infeasible solution for the problem is found. Most of heuristic solvers should use this value.
Infeasible(Infeasible)
The solver proved that the problem is infeasible, i.e. all solutions of the problem are infeasible.
If the solver cannot get the proof of infeasibility,
and just cannot find any feasible solution due to the time limit or due to heuristic algorithm limitation,
the solver should return its best Solution message with feasible field set to false.
Unbounded(Unbounded)
The solver proved that the problem is unbounded.
Implementations
Sourceimpl Result
impl Result
Sourcepub fn merge<B>(
field: &mut Option<Result>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Result>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.