#[non_exhaustive]pub struct Quadratic {
pub rows: Vec<u64>,
pub columns: Vec<u64>,
pub values: Vec<f64>,
pub linear: Option<Linear>,
}Expand description
Quadratic function as a COO-style sparse matrix and linear sparse vector.
COOrdinate format, also known as triplet format, is a way to represent sparse matrices as a list of non-zero elements. It consists of three lists: the row indices, the column indices, and the values of the non-zero elements with following constraints:
- Entries and coordinates sorted by row, then column.
- There are no duplicate entries (i.e. duplicate (i,j) locations)
- Data arrays MAY have explicit zeros.
Note that this matrix is not assured to be symmetric nor upper triangular.
For example, a quadratic function x1^2 + x2^2 + 2x1*x2 can be represented as:
{ rows: \[0, 0, 1\], columns: \[0, 1, 1\], values: \[1, 2, 1\] }, i.e. an upper triangular matrix\[[1, 2\], \[0, 1\]{ rows: \[0, 0, 1, 1\], columns: \[0, 1, 0, 1\], values: \[1, 1, 1, 1\] }, i.e. a symmetric matrix\[[1, 1\], \[1, 1]\]
or even a non-symmetric, non-trianglar matrix as x1^2 + 3x1*x2 - x2*x1 + x2^2:
{ rows: \[0, 0, 1, 1\], columns: \[0, 1, 0, 1\], values: \[1, 3, -1, 1\] }, i.e. a non-symmetric matrix\[[1, 3\], \[-1, 1]\]
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rows: Vec<u64>columns: Vec<u64>values: Vec<f64>linear: Option<Linear>Implementations
Sourceimpl Quadratic
impl Quadratic
pub fn quad_iter(&self) -> impl Iterator<Item = ((u64, u64), f64)> + '_
Sourcepub fn as_linear(self) -> Option<Linear>
pub fn as_linear(self) -> Option<Linear>
Downcast to a linear function if the quadratic function is linear.
Sourcepub fn as_constant(self) -> Option<f64>
pub fn as_constant(self) -> Option<f64>
Downcast to a constant if the quadratic function is constant.
pub fn degree(&self) -> u32
pub fn get_constant(&self) -> f64