#[non_exhaustive]pub struct SampleSet {
pub objectives: Option<SampledValues>,
pub decision_variables: Vec<SampledDecisionVariable>,
pub constraints: Vec<SampledConstraint>,
pub named_functions: Vec<SampledNamedFunction>,
pub feasible: HashMap<u64, bool>,
pub feasible_unrelaxed: HashMap<u64, bool>,
pub feasible_relaxed: HashMap<u64, bool>,
pub sense: i32,
pub metadata: Option<ProcessMetadata>,
pub annotations: HashMap<String, String>,
pub format_version: u32,
}Expand description
Output of the sampling process.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.objectives: Option<SampledValues>decision_variables: Vec<SampledDecisionVariable>constraints: Vec<SampledConstraint>named_functions: Vec<SampledNamedFunction>feasible: HashMap<u64, bool>Feasibility for both remaining and removed constraints of each sample.
The meaning of feasible field in SDK changes between
Python SDK 1.6.0 to 1.7.0.
In Python SDK 1.6.0, feasible represents the feasibility of
remaining constraints of each sample,
i.e. removed constraints (introduced in 1.6.0) are not considered.
After Python SDK 1.7.0, feasible represents the feasibility of
all constraints of each sample.
The feasibility of 1.6.0 is renamed to feasible_relaxed in 1.7.0.
feasible_unrelaxed: HashMap<u64, bool>[Deprecated] This field has been introduced in Python SDK 1.6.0
to represent the feasibility of all constraints of each sample.
The feasible field is used in this sense after Python SDK 1.7.0.
feasible_relaxed: HashMap<u64, bool>Feasibility for remaining (non-removed) constraints of each sample.
sense: i32Minimize or Maximize
metadata: Option<ProcessMetadata>OMMX-defined provenance metadata for this SampleSet.
annotations: HashMap<String, String>User-defined or third-party extension annotations.
OMMX-reserved metadata must use explicit fields such as metadata.
Keys in this map must be valid reverse-domain names and must not start with
org.ommx.v1..
format_version: u32Format version of this message for forward compatibility checks.
See Instance.format_version for semantics.
Implementations